@@ -79,7 +79,12 @@ namespace Beagle {
 			// use the default socket name when passed null
 			if (client_name == null)
 				client_name = "socket";
-			this.socket_name = Path.Combine (PathFinder.StorageDir, client_name);
+
+			string storage_dir = PathFinder.GetRemoteStorageDir (false);
+			if (storage_dir == null)
+				throw new System.Net.Sockets.SocketException ();
+
+			this.socket_name = Path.Combine (storage_dir, client_name);
 		}
 
 		public Client () : this (null)
@@ -119,7 +124,18 @@ namespace Beagle {
 			// The socket may be shut down at some point here.  It
 			// is the caller's responsibility to handle the error
 			// correctly.
+#if ENABLE_XML_DUMP
+			MemoryStream mem_stream = new MemoryStream ();
+			req_serializer.Serialize (mem_stream, new RequestWrapper (request));
+			mem_stream.Seek (0, SeekOrigin.Begin);
+			StreamReader r = new StreamReader (mem_stream);
+			Logger.Log.Debug ("Sending request:\n{0}", r.ReadToEnd ());
+			mem_stream.Seek (0, SeekOrigin.Begin);
+			mem_stream.WriteTo (stream);
+			mem_stream.Close ();
+#else
 			req_serializer.Serialize (stream, new RequestWrapper (request));
+#endif
 			// Send end of message marker
 			stream.WriteByte (0xff);
 			stream.Flush ();
@@ -227,6 +243,74 @@ namespace Beagle {
 				BeginRead ();
 		}
 
+		public void SendAsyncBlocking (RequestMessage request)
+		{
+			Exception ex = null;
+
+			try {
+				SendRequest (request);
+			} catch (IOException e) {
+				ex = e;
+			} catch (SocketException e) {
+				ex = e;
+			}
+
+			if (ex != null) {
+				ResponseMessage resp = new ErrorResponse (ex);
+				
+				if (this.AsyncResponseEvent != null)
+					this.AsyncResponseEvent (resp);
+				return;
+			}
+			
+
+			NetworkStream stream = this.client.GetStream ();
+			MemoryStream deserialize_stream = new MemoryStream ();
+
+			// This buffer is annoyingly small on purpose, to avoid
+			// having to deal with the case of multiple messages
+			// in a single block.
+			byte [] buffer = new byte [32];
+
+			while (! this.closed) {
+
+				Array.Clear (buffer, 0, buffer.Length);
+
+				int bytes_read;
+				bytes_read = stream.Read (buffer, 0, buffer.Length);
+				if (bytes_read == 0)
+					break;
+
+				int end_index;
+				end_index = ArrayFu.IndexOfByte (buffer, (byte) 0xff);
+
+				if (end_index == -1) {
+					deserialize_stream.Write (buffer, 0, bytes_read);
+				} else {
+					deserialize_stream.Write (buffer, 0, end_index);
+					deserialize_stream.Seek (0, SeekOrigin.Begin);
+
+					ResponseMessage resp;
+					try {
+						ResponseWrapper wrapper;
+						wrapper = (ResponseWrapper) resp_serializer.Deserialize (deserialize_stream);
+						
+						resp = wrapper.Message;
+					} catch (Exception e) {
+						resp = new ErrorResponse (e);
+					}
+
+					if (this.AsyncResponseEvent != null)
+						this.AsyncResponseEvent (resp);
+
+					deserialize_stream.Close ();
+					deserialize_stream = new MemoryStream ();
+					if (bytes_read - end_index - 1 > 0)
+						deserialize_stream.Write (buffer, end_index+1, bytes_read-end_index-1);
+				}
+			}
+		}
+
 
 		public ResponseMessage Send (RequestMessage request)
 		{
