@@ -30,7 +30,9 @@ using System.Collections;
 using System.IO;
 using System.Text;
 using System.Xml;
+
 using Beagle.Util;
+using Beagle.Daemon;
 
 using ICSharpCode.SharpZipLib.Zip;
 
@@ -44,20 +46,20 @@ namespace Beagle.Filters {
 		public FilterOpenOffice () 
 		{
 			// OO 1.0 mime types
-			AddSupportedMimeType ("application/vnd.sun.xml.writer");
-			AddSupportedMimeType ("application/vnd.sun.xml.writer.template");
-			AddSupportedMimeType ("application/vnd.sun.xml.calc");
-			AddSupportedMimeType ("application/vnd.sun.xml.calc.template");
-			AddSupportedMimeType ("application/vnd.sun.xml.impress");
-			AddSupportedMimeType ("application/vnd.sun.xml.impress.template");
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.sun.xml.writer"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.sun.xml.writer.template"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.sun.xml.calc"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.sun.xml.calc.template"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.sun.xml.impress"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.sun.xml.impress.template"));
 
 			// OO 2.0 mime types
-			AddSupportedMimeType ("application/vnd.oasis.opendocument.text");
-			AddSupportedMimeType ("application/vnd.oasis.opendocument.text-template");
-			AddSupportedMimeType ("application/vnd.oasis.opendocument.spreadsheet");
-			AddSupportedMimeType ("application/vnd.oasis.opendocument.spreadsheet-template");
-			AddSupportedMimeType ("application/vnd.oasis.opendocument.presentation");
-			AddSupportedMimeType ("application/vnd.oasis.opendocument.presentation-template");
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.oasis.opendocument.text"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.oasis.opendocument.text-template"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.oasis.opendocument.spreadsheet"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.oasis.opendocument.spreadsheet-template"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.oasis.opendocument.presentation"));
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.oasis.opendocument.presentation-template"));
 
 			SnippetMode = true;
 			odtFormat = false;
