@@ -1,4 +1,3 @@
-/* -*- Mode: csharp; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 //
 // FilterPPT.cs
 //
@@ -32,6 +31,7 @@ using System.IO;
 using System.Text;
 using Gsf;
 
+using Beagle.Daemon;
 using Beagle.Util;
 
 internal class RecordType
@@ -391,7 +391,7 @@ namespace Beagle.Filters {
 		string FileName;
 		public FilterPPT () 
 		{
-			AddSupportedMimeType ("application/vnd.ms-powerpoint");
+			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.ms-powerpoint"));
 			textType = TextType.Invalid;
 			file = null;
 			FileName = null;
@@ -476,68 +476,68 @@ namespace Beagle.Filters {
 
 		private void ExtractMetaData (Input sumStream, Input docSumStream)
 		{
-			DocMetaData sumMeta = null;
+			DocMetaData sumMeta = new DocMetaData ();
 			if (sumStream != null)
-				sumMeta = Msole.MetadataReadReal (sumStream);
+				Msole.MetadataRead (sumStream, sumMeta);
 			else
 				Logger.Log.Error ("SummaryInformationStream not found in {0}", FileName);
 
-			DocMetaData docSumMeta = null;
+			DocMetaData docSumMeta = new DocMetaData ();
 			if (docSumStream != null)
-				docSumMeta = Msole.MetadataReadReal (docSumStream);
+				Msole.MetadataRead (docSumStream, docSumMeta);
 			else
 				Logger.Log.Error ("DocumentSummaryInformationStream not found in {0}", FileName);
 
 			DocProp prop = null;
 			string str = null;
 			if (sumMeta != null) {
-				prop = sumMeta.GetProp ("dc:title");
+				prop = sumMeta.Lookup ("dc:title");
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("dc:title", str));
 
 				str = null;
-				prop = sumMeta.GetProp ("dc:subject");			
+				prop = sumMeta.Lookup ("dc:subject");			
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);			
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("dc:subject", str));
 
 				str = null;
-				prop = sumMeta.GetProp ("dc:description");		
+				prop = sumMeta.Lookup ("dc:description");		
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);			
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("dc:description", str));
 
 				str = null;
-				prop = sumMeta.GetProp ("gsf:keywords");
+				prop = sumMeta.Lookup ("gsf:keywords");
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("fixme:keywords", str));
 
 				str = null;
-				prop = sumMeta.GetProp ("gsf:creator");
+				prop = sumMeta.Lookup ("gsf:creator");
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("fixme:author", str));
 			}
 			
 			if (docSumMeta != null) {
 				str = null;
-				prop = docSumMeta.GetProp ("gsf:company");
+				prop = docSumMeta.Lookup ("gsf:company");
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("fixme:company", str));
 
 				str = null;
-				prop = docSumMeta.GetProp ("gsf:slide-count");
+				prop = docSumMeta.Lookup ("gsf:slide-count");
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
+					str = (string) prop.Val;
 				if (str != null && str.Length > 0)
 					AddProperty (Beagle.Property.New ("fixme:slide-count", str));
 			}
@@ -550,79 +550,111 @@ namespace Beagle.Filters {
 			int childCount = 0;
 			int found = 0;
 			
-			if (file == null)
+			if (file == null) {
+				Finished ();
 				return;
-
-			// FIXME: Should try to use Encoding instead of 
-			// string.IndexOf ()... Hacky stuff ;-)
-			childCount = file.NumChildren();
-			for (int i = 0; i < childCount && found != 2; i++) {
-				str = file.NameByIndex (i);	
-				if (str.IndexOf ("SummaryInformation") > -1 && found < 1) {
-					sumStream = file.ChildByIndex (i);
-					found = 1;
-				}
-				else if (str.IndexOf ("DocumentSummaryInformation") > -1) {
-					docSumStream = file.ChildByIndex (i);
-					found = 2;
-				}
 			}
-			ExtractMetaData (sumStream, docSumStream);
+			
+			try {
+				// FIXME: Should try to use Encoding instead of 
+				// string.IndexOf ()... Hacky stuff ;-)
+				childCount = file.NumChildren();
+				for (int i = 0; i < childCount && found != 2; i++) {
+					str = file.NameByIndex (i);	
+					if (str.IndexOf ("SummaryInformation") > -1 && found < 1) {
+						sumStream = file.ChildByIndex (i);
+						found = 1;
+					}
+					else if (str.IndexOf ("DocumentSummaryInformation") > -1) {
+						docSumStream = file.ChildByIndex (i);
+						found = 2;
+					}
+				}
+				ExtractMetaData (sumStream, docSumStream);
+			} catch (Exception e) {
+				Logger.Log.Error ("Exception occurred duing DoPullProperties.");
+				Logger.Log.Error (e);
+				Error ();
+			}
 		}
 
 		override protected void DoPull ()
 		{
-			if (file == null)
+			if (file == null) {
+				Finished ();
 				return;
+			}
 
 			Input stream = null;
-			stream = file.ChildByName ("PowerPoint Document");
+			try {
+				stream = file.ChildByName ("PowerPoint Document");
 
-			if (stream != null) {
+				if (stream != null) {
 
-				// The parsing was getting terminated when "EndDocument"
-				// container was parsed.  We need to continue our 
-				// parsing till the end of the file, since, some of the
-				// slides do persist after the actual "Document" 
-				// container.
-				// PPTs exported from OO.o actually writes almost all the slides
-				// after "Document" container.
-				// And certain PPTs do have some slides in after
-				// "Document" container.
-				while (!stream.Eof)
-					ParseElement (stream);
-			} else {
-				Logger.Log.Error ("Ole stream not found in {0}.  Content extraction skipped.", FileName);
+					// The parsing was getting terminated when "EndDocument"
+					// container was parsed.  We need to continue our 
+					// parsing till the end of the file, since, some of the
+					// slides do persist after the actual "Document" 
+					// container.
+					// PPTs exported from OO.o actually writes almost all the slides
+					// after "Document" container.
+					// And certain PPTs do have some slides in after
+					// "Document" container.
+					while (!stream.Eof)
+						ParseElement (stream);
+				} else {
+					Logger.Log.Error ("Ole stream not found in {0}.  Content extraction skipped.", FileName);
+				}
+
+				Finished ();
+			} catch (Exception e) {
+				Logger.Log.Error ("Exception {0} occurred during DoPull.", e.Message);
+				Error ();
 			}
-			Finished();
 		}
 
 		override protected void DoOpen (FileInfo info)
 		{
 			FileName = info.FullName;
 
-			Gsf.Global.Init ();
-			Input input = Input.MmapNew (info.FullName);
-			if (input != null) {
-				input = input.Uncompress();
-				file = new InfileMSOle (input);
-			} else {
-				Logger.Log.Error ("Unable to open {0}", info.FullName);
-				Finished ();
+			try {
+				Gsf.Global.Init ();
+				Input input = Input.MmapNew (info.FullName);
+				if (input != null) {
+					input = input.Uncompress();
+					file = new InfileMSOle (input);
+				}
+				if (input == null || file == null) {
+					Logger.Log.Error ("Unable to open [{0}] ",info.FullName);
+					Error ();
+					return;
+				}
+				
+			} catch (Exception e) {
+				Logger.Log.Error ("Unable to open "+info.FullName);
+				Error ();
+				return;
 			}
-
+			
 			// PPT 95/97-2000 format contains a "PP97_DUALSTORAGE", which is required
 			// to index PPT 97-2000 files.
 			// We don't support PPT 95 files, however, we happily accept patches ;-)
 
 			Input dualStorTemp = null;
-			if ((dualStorTemp = file.ChildByName ("PP97_DUALSTORAGE")) != null) {
-				// "PP97_DUALSTORAGE" is a storage containing some streams
-				if (dualStorTemp.Handle != IntPtr.Zero)
-					file = (Gsf.Infile) GLib.Object.GetObject (dualStorTemp.Handle);
-			} else if ((dualStorTemp = file.ChildByName ("Header")) != null) {
-				Logger.Log.Error ("{0} is a PPT 95 file.  Beagle does not support PPT 95 files. Skipping...", FileName);
-				Finished ();
+			try {
+				if ((dualStorTemp = file.ChildByName ("PP97_DUALSTORAGE")) != null) {
+					// "PP97_DUALSTORAGE" is a storage containing some streams
+					if (dualStorTemp.Handle != IntPtr.Zero)
+						file = (Gsf.Infile) GLib.Object.GetObject (dualStorTemp.Handle);
+				} else if (((dualStorTemp = file.ChildByName ("Header")) != null) ||
+					   ((dualStorTemp = file.ChildByName ("PowerPoint Document")) == null)) {
+					Logger.Log.Error ("{0} is a PPT 95/4.0 file.  Beagle does not support PPT 95 files. Skipping...", FileName);
+					Error ();
+				}
+			} catch (Exception e) {
+				
+				Logger.Log.Error ("Unable to open OleFile stream of "+info.FullName);
+				Error ();
 			}
 		}
 
