@@ -40,7 +40,7 @@ namespace Beagle.Filters {
 			OriginalIsText = true;
 		}
 
-		const long LENGTH_CUTOFF = 1024 * 1024; // 1 Mb
+		const long LENGTH_CUTOFF = 5 * 1024 * 1024; // 5 Mb
 
 		override protected void DoOpen (FileInfo file)
 		{
@@ -49,7 +49,7 @@ namespace Beagle.Filters {
 			// that will tend to clog up our indexes.
 			if (file.Length > LENGTH_CUTOFF) {
 				Beagle.Util.Logger.Log.Debug ("{0} is too large to filter!", file.FullName);
-				Finished ();
+				Error ();
 			}
 		}
 
