@@ -16,16 +16,16 @@ using System.Text;
 namespace Beagle.Util {
 namespace Camel {
 	
-	public enum CamelFlags {
-		ANSWERED     = 1<<0,
-		DELETED      = 1<<1,
-		DRAFT        = 1<<2,
-		FLAGGED      = 1<<3,
-		SEEN         = 1<<4,
-		ATTACHMENTS  = 1<<5,
-		ANSWERED_ALL = 1<<6,
-		JUNK         = 1<<7,
-		SECURE       = 1<<8
+	public enum CamelFlags : uint {
+		Answered     = 1 << 0,
+		Deleted      = 1 << 1,
+		Draft        = 1 << 2,
+		Flagged      = 1 << 3,
+		Seen         = 1 << 4,
+		Attachments  = 1 << 5,
+		AnsweredAll  = 1 << 6,
+		Junk         = 1 << 7,
+		Secure       = 1 << 8
 	}
 	
 public abstract class Summary : IEnumerable { 
@@ -195,7 +195,6 @@ public abstract class Summary : IEnumerable {
 		public string uid, subject, from, to, cc, mlist;
 		public uint size, flags;
 		public DateTime sent, received;
-		public int x, y;
 
 		private void SkipContentInfo (FileStream f)
 		{
@@ -275,35 +274,43 @@ public abstract class Summary : IEnumerable {
 		
 		private bool CheckFlag (CamelFlags test)
 		{
-			return (flags & (int) test) == (int) test;
+			return (flags & (uint) test) == (uint) test;
 		}
 		
 		public bool IsAnswered {
-			get { return CheckFlag (CamelFlags.ANSWERED); }
+			get { return CheckFlag (CamelFlags.Answered); }
 		}
 
 		public bool IsDeleted {
-			get { return CheckFlag (CamelFlags.DELETED); }
+			get { return CheckFlag (CamelFlags.Deleted); }
 		}
 
 		public bool IsDraft {
-			get { return CheckFlag (CamelFlags.DRAFT); }
+			get { return CheckFlag (CamelFlags.Draft); }
 		}
 
 		public bool IsFlagged {
-			get { return CheckFlag (CamelFlags.FLAGGED); }
+			get { return CheckFlag (CamelFlags.Flagged); }
 		}
 
 		public bool IsSeen {
-			get { return CheckFlag (CamelFlags.SEEN); }
+			get { return CheckFlag (CamelFlags.Seen); }
 		}
 
 		public bool HasAttachments {
-			get { return CheckFlag (CamelFlags.ATTACHMENTS); }
+			get { return CheckFlag (CamelFlags.Attachments); }
 		}
 
 		public bool IsAnsweredAll {
-			get { return CheckFlag (CamelFlags.ANSWERED_ALL); }
+			get { return CheckFlag (CamelFlags.AnsweredAll); }
+		}
+
+		public bool IsJunk {
+			get { return CheckFlag (CamelFlags.Junk); }
+		}
+
+		public bool IsSecure {
+			get { return CheckFlag (CamelFlags.Secure); }
 		}
 	}
 
@@ -408,16 +415,30 @@ public abstract class Summary : IEnumerable {
 		
 		public SummaryHeader (FileStream f)
 		{
+			bool legacy;
+
 			version = Decode.FixedInt (f);
+
+			if (version > 0xff && (version & 0xff) < 12)
+				throw new Exception ("Summary header version too low");
+
+			if (version < 0x100 && version >= 13)
+				legacy = false;
+			else
+				legacy = true;
+
 			flags   = Decode.FixedInt (f);
 			nextuid = Decode.FixedInt (f);
 			time    = Decode.Time (f);
 			count   = Decode.FixedInt (f);
-			unread  = Decode.FixedInt (f);
-			deleted = Decode.FixedInt (f);
-			junk    = Decode.FixedInt (f);
 
-			//Console.WriteLine ("V={0} time={1}, count={2} unread={3} deleted={4} junk={5}", version, time, count, unread, deleted, junk);
+			if (!legacy) {
+				unread  = Decode.FixedInt (f);
+				deleted = Decode.FixedInt (f);
+				junk    = Decode.FixedInt (f);
+			}
+
+			//Console.WriteLine ("V={0} ({1}) time={2}, count={3} unread={4} deleted={5} junk={6}", version, version & 0xff, time, count, unread, deleted, junk);
 		}
 	}
 
@@ -431,6 +452,8 @@ public abstract class Summary : IEnumerable {
 			local_version = Decode.FixedInt (f);
 			mbox_version = Decode.FixedInt (f);
 			folder_size = Decode.FixedInt (f);
+
+			//Console.WriteLine ("local_version={0}  mbox_version={1}  folder_size={2}", local_version, mbox_version, folder_size);
 		}
 	}
 
@@ -438,17 +461,28 @@ public abstract class Summary : IEnumerable {
 		
 		public ImapSummaryHeader (FileStream f) : base (f)
 		{
-			int version = Decode.FixedInt (f);
+			// Check for legacy version
+			if (base.version != 0x30c) { // 780
+				int version = Decode.FixedInt (f);
 
-			// Right now we only support summary versions 1 through 3
-			if (version > 3)
-				throw new Exception (String.Format ("Reported summary version ({0}) is too new", version));
+				//Console.WriteLine ("imap version={0}", version);
 
-			if (version == 2)
-				Decode.FixedInt (f);
+				if (version < 0)
+					throw new Exception ("IMAP summary version too low");
 
-			// validity
-			Decode.SkipFixedInt (f);
+				// Right now we only support summary versions 1 through 3
+				if (version > 3)
+					throw new Exception (String.Format ("Reported summary version ({0}) is too new", version));
+
+				if (version == 2)
+					Decode.FixedInt (f);
+
+				// validity
+				Decode.SkipFixedInt (f);
+			} else {
+				// validity
+				Decode.UInt (f);
+			}
 		}
 	}
 	
@@ -536,10 +570,14 @@ public abstract class Summary : IEnumerable {
 
 		public static DateTime Time (FileStream f)
 		{
-			byte [] b = new byte [4];
+			long seconds = 0;
 
-			f.Read (b, 0, 4);
-			long seconds = (b [0] << 24) | (b [1] << 16) | (b [2] << 8) | b [3];
+			// FIXME: Is it safe to assume that sizeof (time_t) == IntPtr.Size?  Probably not.
+			for (int i = IntPtr.Size - 1; i >= 0; i--) {
+				int v = f.ReadByte ();
+
+				seconds |= v << (i * 8);
+			}
 
 			if (seconds == 0)
 				return new DateTime (0);
