@@ -42,13 +42,6 @@ namespace Beagle.Daemon {
 		int remote_index_minor_version = 0;
 		int last_item_count = -1;
 
-		RemoteIndexerRequest pending_request = new RemoteIndexerRequest ();
-		object pending_request_lock = new object ();
-
-		public event IIndexerChangedHandler ChangedEvent;
-		public event IIndexerChildIndexableHandler ChildIndexableEvent;
-		public event IIndexerUrisFilteredHandler UrisFilteredEvent;
-
 		static RemoteIndexer ()
 		{
 			string bihp = Environment.GetEnvironmentVariable ("_BEAGLED_INDEX_HELPER_PATH");
@@ -72,41 +65,38 @@ namespace Beagle.Daemon {
 			this.remote_index_minor_version = minor_version;
 		}
 
-		public void Add (Indexable indexable)
+		public IndexerReceipt [] Flush (IndexerRequest request)
 		{
-			indexable.StoreStream ();
-			lock (pending_request_lock)
-				pending_request.Add (indexable);
-		}
+			// If there isn't actually any work to do, just return
+			// an empty array.
+			if (request.IsEmpty)
+				return new IndexerReceipt [0];
 
-		public void Remove (Uri uri)
-		{
-			lock (pending_request_lock)
-				pending_request.Remove (uri);
-		}
-
-		public void Rename (Uri old_uri, Uri new_uri)
-		{
-			lock (pending_request_lock)
-				pending_request.Rename (old_uri, new_uri);
-		}
-
-		public void Flush ()
-		{
-			RemoteIndexerRequest flushed_request = null;
-			lock (pending_request) {
-				flushed_request = pending_request;
-				pending_request = new RemoteIndexerRequest ();
+			// Iterate through the items in the IndexerRequest to
+			// store the streams before passing them to the helper.
+			foreach (Indexable indexable in request.Indexables) {
+				if (indexable.Type == IndexableType.Add)
+					indexable.StoreStream ();
 			}
 
+			RemoteIndexerRequest remote_request;
+			remote_request = new RemoteIndexerRequest ();
+			remote_request.RemoteIndexName = this.remote_index_name;
+			remote_request.RemoteIndexMinorVersion = this.remote_index_minor_version;
+			remote_request.Request = request;
+			
 			RemoteIndexerResponse response;
-			response = SendRequest (flushed_request);
+			response = SendRequest (remote_request);
 
 			if (response == null) {
 				Logger.Log.Error ("Something terrible happened --- Flush failed");
-			} else {
-				flushed_request.FireEvent (this, ChangedEvent);
+				request.Cleanup ();
+				return null;
 			}
+			
+			last_item_count = response.ItemCount;
+
+			return response.Receipts;
 		}
 
 		public int GetItemCount ()
@@ -114,10 +104,17 @@ namespace Beagle.Daemon {
 			if (last_item_count == -1) {
 				// Send an empty indexing request to cause the last item count to be
 				// initialized.
-				RemoteIndexerRequest request = new RemoteIndexerRequest ();
-				if (SendRequest (request) == null) 
+				RemoteIndexerRequest request;
+				request = new RemoteIndexerRequest ();
+
+				RemoteIndexerResponse response;
+				response = SendRequest (request);
+				if (response != null)
+					last_item_count = response.ItemCount;
+				else
 					Logger.Log.Error ("Something terrible happened --- GetItemCount failed");
 			}
+
 			return last_item_count;
 		}
 
@@ -144,7 +141,7 @@ namespace Beagle.Daemon {
 				//Logger.Log.Debug ("Sending request!");
 				try {
 					response = request.Send () as RemoteIndexerResponse;
-					Logger.Log.Debug ("Done sending request");
+					//Logger.Log.Debug ("Done sending request");
 				} catch (ResponseMessageException ex) {
 					Logger.Log.Debug ("Caught ResponseMessageException: {0}", ex.Message);
 				} catch (System.Net.Sockets.SocketException ex) {
@@ -170,28 +167,9 @@ namespace Beagle.Daemon {
 				}
 			}
 
-			if (response != null) {
-				//Logger.Log.Debug ("Got response!");
-				last_item_count = response.ItemCount;
-
-				if (response.ChildIndexables != null) {
-					Logger.Log.Debug ("Sending {0} child indexables from helper",
-							  response.ChildIndexables.Length);
-
-					if (response.ChildIndexables.Length > 0 && ChildIndexableEvent != null)
-						ChildIndexableEvent (response.ChildIndexables);
-				}
-
-				if (response.UrisFiltered != null) {
-					Logger.Log.Debug ("Sending {0} filtered uris from helper", response.UrisFiltered.Length);
-
-					if (response.UrisFiltered.Length > 0 && UrisFilteredEvent != null)
-						UrisFilteredEvent (response.UrisFiltered);
-				}
-			} else if (exception_count >= 5) {
+			if (response == null && exception_count >= 5)
 				Logger.Log.Error ("Exception limit exceeded trying to activate a helper.  Giving up on indexing!");
-			}
-	
+
 			return response;
 		}
 
@@ -199,8 +177,13 @@ namespace Beagle.Daemon {
 
 		static bool CheckHelper ()
 		{
+			string storage_dir = PathFinder.GetRemoteStorageDir (false);
+
+			if (storage_dir == null)
+				return false;
+
 			// FIXME: We shouldn't need to know the path to the helper socket.
-			string socket_name = Path.Combine (PathFinder.StorageDir, "socket-helper");
+			string socket_name = Path.Combine (storage_dir, "socket-helper");
 
 			if (! File.Exists (socket_name))
 				return false;
